@@ -50,6 +50,7 @@ from mrjob.retry import RetryWrapper
 from mrjob.runner import MRJobRunner, GLOB_RE
 from mrjob.util import cmd_line
 
+
 log = logging.getLogger('mrjob.emr')
 
 S3_URI_RE = re.compile(r'^s3://([A-Za-z0-9-\.]+)/(.*)$')
@@ -94,6 +95,7 @@ REGION_TO_S3_ENDPOINT = {
     '': 's3.amazonaws.com',
 }
 
+
 def parse_s3_uri(uri):
     """Parse an S3 URI into (bucket, key)
 
@@ -108,16 +110,20 @@ def parse_s3_uri(uri):
     else:
         raise ValueError('Invalid S3 URI: %s' % uri)
 
+
 def s3_key_to_uri(s3_key):
     """Convert a boto Key object into an ``s3://`` URI"""
     return 's3://%s/%s' % (s3_key.bucket.name, s3_key.name)
 
+
 def _to_timestamp(iso8601_time):
     return time.mktime(time.strptime(iso8601_time, boto.utils.ISO8601))
 
+
 def _to_datetime(iso8601_time):
     return datetime.datetime.strptime(iso8601_time, boto.utils.ISO8601)
 
+
 def describe_all_job_flows(emr_conn, states=None, jobflow_ids=None,
                            created_after=None, created_before=None):
     """Iteratively call ``EmrConnection.describe_job_flows()`` until we really
@@ -181,6 +187,7 @@ def describe_all_job_flows(emr_conn, states=None, jobflow_ids=None,
 
     return all_job_flows
 
+
 class EMRJobRunner(MRJobRunner):
     """Runs an :py:class:`~mrjob.job.MRJob` on Amazon Elastic MapReduce.
 
@@ -558,10 +565,6 @@ class EMRJobRunner(MRJobRunner):
 
         log.info('Opening ssh tunnel to Hadoop job tracker')
 
-        bind_ports = random.sample(
-            self._opts['ssh_bind_ports'],
-            min(MAX_SSH_RETRIES, len(self._opts['ssh_bind_ports'])))
-
         # if ssh detects that a host key has changed, it will silently not
         # open the tunnel, so make a fake empty known_hosts file and use that.
         # (you can actually use /dev/null as your known hosts file, but
@@ -575,7 +578,7 @@ class EMRJobRunner(MRJobRunner):
             fake_known_hosts_file,))
 
         bind_port = None
-        for bind_port in bind_ports:
+        for bind_port in self._pick_ssh_bind_ports():
             args = [
                 self._opts['ssh_bin'],
                 '-o', 'VerifyHostKeyDNS=no',
@@ -611,6 +614,21 @@ class EMRJobRunner(MRJobRunner):
             self._show_tracker_progress = True
             log.info( 'Connect to job tracker at: %s' % (self._tracker_url))
 
+    def _pick_ssh_bind_ports(self):
+        """Pick a list of ports to try binding our SSH tunnel to.
+
+        We will try to bind the same port for any given job flow (Issue #67)
+        """
+        # don't perturb the random number generator
+        random_state = random.getstate()
+        try:
+            # seed random port selection on job flow ID
+            random.seed(self._emr_job_flow_id)
+            num_picks = min(MAX_SSH_RETRIES, len(self._opts['ssh_bind_ports']))
+            return random.sample(self._opts['ssh_bind_ports'], num_picks)
+        finally:
+            random.setstate(random_state)
+
     def cleanup(self, mode=None):
         super(EMRJobRunner, self).cleanup(mode=mode)
 
@@ -723,7 +741,6 @@ class EMRJobRunner(MRJobRunner):
 
         log.info('Job flow created with ID: %s' % emr_job_flow_id)
         return emr_job_flow_id
-
     def _build_steps(self):
         """Return a list of boto Step objects corresponding to the
         steps we want to run."""
@@ -780,7 +797,7 @@ class EMRJobRunner(MRJobRunner):
             # other arguments passed directly to hadoop streaming
             step_args = []
 
-            for key, value in sorted(self._cmdenv.iteritems()):
+            for key, value in sorted(self._get_cmdenv().iteritems()):
                 step_args.extend(['-cmdenv', '%s=%s' % (key, value)])
 
             for key, value in sorted(self._opts['jobconf'].iteritems()):
@@ -1279,13 +1296,14 @@ class EMRJobRunner(MRJobRunner):
         # bootstrap mrjob
         if self._opts['bootstrap_mrjob']:
             writeln('# bootstrap mrjob')
-            writeln("mrjob_dir = os.path.join(distutils.sysconfig.get_python_lib(), 'mrjob')")
-            writeln("check_call(['sudo', 'mkdir', mrjob_dir])")
-            writeln("check_call(['sudo', 'tar', 'xfz', %r, '-C', mrjob_dir])" %
-                    self._mrjob_tar_gz_file['name'])
+            writeln("site_packages = distutils.sysconfig.get_python_lib()")
+            writeln(
+                "check_call(['sudo', 'tar', 'xfz', %r, '-C', site_packages])" %
+                self._mrjob_tar_gz_file['name'])
             # re-compile pyc files now, since mappers/reducers can't
             # write to this directory. Don't fail if there is extra
             # un-compileable crud in the tarball.
+            writeln("mrjob_dir = os.path.join(site_packages, 'mrjob')")
             writeln("call(['sudo', 'python', '-m', 'compileall', '-f', mrjob_dir])")
             writeln()
 
@@ -1468,10 +1486,13 @@ class EMRJobRunner(MRJobRunner):
         """Wrap a given boto Connection object so that it can retry when
         throttled."""
         def retry_if(ex):
-            """Retry if we get a server error indicating throttling."""
+            """Retry if we get a server error indicating throttling. Also
+            handle spurious 505s that are thought to be part of a load
+            balancer issue inside AWS."""
             return ((isinstance(ex, boto.exception.BotoServerError) and
                      ('Throttling' in ex.body or
-                      'RequestExpired' in ex.body)) or
+                      'RequestExpired' in ex.body or
+                      ex.status == 505)) or
                     (isinstance(ex, socket.error) and
                      ex.args in ((104, 'Connection reset by peer'),
                                  (110, 'Connection timed out'))))
