@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp and Contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -373,14 +373,17 @@ class MRJob(object):
         Called from :py:meth:`run`. You'd probably only want to call this
         directly from automated tests.
         """
-        log_to_stream(
-            name='mrjob', stream=self.stderr, debug=self.options.verbose)
+        if not self.options.quiet:
+            log_to_stream(
+                name='mrjob', stream=self.stderr, debug=self.options.verbose)
 
         with self.make_runner() as runner:
             runner.run()
-            for line in runner.stream_output():
-                self.stdout.write(line)
-            self.stdout.flush()
+
+            if not self.options.no_output:
+                for line in runner.stream_output():
+                    self.stdout.write(line)
+                self.stdout.flush()
 
     def run_mapper(self, step_num=0):
         """Run the mapper and final mapper action for the given step.
@@ -633,6 +636,10 @@ class MRJob(object):
         self.runner_opt_group.add_option(
             '--no-conf', dest='conf_path', action='store_false',
             help="Don't load mrjob.conf even if it's available")
+        self.runner_opt_group.add_option(
+            '--no-output', dest='no_output',
+            default=False, action='store_true',
+            help="Don't stream output after job completion")
         self.runner_opt_group.add_option(
             '--cleanup', dest='cleanup',
             choices=CLEANUP_CHOICES, default=CLEANUP_DEFAULT,
@@ -674,15 +681,19 @@ class MRJob(object):
             'multiple times.')
 
         self.runner_opt_group.add_option(
-        	'--cmdenv', dest='cmdenv', default={}, action='set_key',
+            '--cmdenv', dest='cmdenv', default={}, action='set_key',
             help='set an environment variable for your job inside Hadoop '
             'streaming. Must take the form KEY=VALUE. You can use --cmdenv '
             'multiple times.')
 
         self.runner_opt_group.add_option(
-            '--hadoop-arg', dest='hadoop_arg', default=[], action='append',
-            help='Argument of any type to pass to hadoop '
-            'streaming. You can use --hadoop arg multiple times.')
+            '--hadoop-arg', dest='hadoop_extra_args', default=[],
+            action='append', help='Argument of any type to pass to hadoop '
+            'streaming. You can use --hadoop-arg multiple times.')
+
+        self.runner_opt_group.add_option(
+            '--python-bin', dest='python_bin', default=None,
+            help='Name/path of alternate python binary for mappers/reducers.')
 
         # options for running the job on Hadoop
         self.hadoop_opt_group = OptionGroup(
@@ -786,7 +797,8 @@ class MRJob(object):
         We suggest against sending Berkeley DBs to your job, as
         Berkeley DB is not forwards-compatiable (so a Berkeley DB that you
         construct on your computer may not be readable from within
-        EMR). Use SQLite databases instead!
+        Hadoop). Use SQLite databases instead. If all you need is an on-disk
+        hash table, try out the :py:mod:`sqlite3dbm` module.
         """
         pass_opt = self.option_parser.add_option(*args, **kwargs)
 
@@ -857,6 +869,7 @@ class MRJob(object):
             'conf_path': self.options.conf_path,
             'extra_args': self.generate_passthrough_arguments(),
             'file_upload_args': self.generate_file_upload_args(),
+            'hadoop_extra_args': self.options.hadoop_extra_args,
             'input_paths': self.args,
             'jobconf': self.options.jobconf,
             'mr_job_script': self.mr_job_script(),
@@ -866,6 +879,7 @@ class MRJob(object):
             'stdin': self.stdin,
             'upload_archives': self.options.upload_archives,
             'upload_files': self.options.upload_files,
+            'python_bin': self.options.python_bin,
         }
 
     def local_job_runner_kwargs(self):
