@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Utility functions for MRJob that have no external dependencies."""
+
 # don't add imports here that aren't part of the standard Python library,
 # since MRJobs need to run in Amazon's generic EMR environment
 from __future__ import with_statement
@@ -28,12 +29,14 @@ import sys
 import tarfile
 import zipfile
 
+
 def cmd_line(args):
     """build a command line that works in a shell.
     """
     args = [str(x) for x in args]
     return ' '.join(pipes.quote(x) for x in args)
 
+
 def expand_path(path):
     """Resolve ``~`` (home dir) and environment variables in *path*.
 
@@ -44,6 +47,7 @@ def expand_path(path):
     else:
         return os.path.expanduser(os.path.expandvars(path))
 
+
 def file_ext(path):
     """return the file extension, including the ``.``
 
@@ -56,6 +60,7 @@ def file_ext(path):
         return ''
     return filename[dot_index:]
 
+
 def log_to_stream(name=None, stream=None, format=None, level=None, debug=False):
     """Set up logging.
 
@@ -86,6 +91,7 @@ def log_to_stream(name=None, stream=None, format=None, level=None, debug=False):
     logger.setLevel(level)
     logger.addHandler(handler)
 
+
 def read_input(path, stdin=None):
     """Stream input the way Hadoop would.
 
@@ -138,6 +144,7 @@ def read_input(path, stdin=None):
     for line in f:
         yield line
 
+
 # Thanks to http://lybniz2.sourceforge.net/safeeval.html for
 # explaining how to do this!
 def safeeval(expr, globals=None, locals=None):
@@ -158,7 +165,7 @@ def safeeval(expr, globals=None, locals=None):
     return eval(expr, safe_globals, locals)
 
 
-def tar_and_gzip(dir, out_path, filter=None):
+def tar_and_gzip(dir, out_path, filter=None, prefix=''):
     """Tar and gzip the given *dir* to a tarball at *out_path*.
 
     If we encounter symlinks, include the actual file, not the symlink.
@@ -168,6 +175,8 @@ def tar_and_gzip(dir, out_path, filter=None):
     :type out_path: str
     :param out_path: where to write the tarball too
     :param filter: if defined, a function that takes paths (relative to *dir* and returns ``True`` if we should keep them
+    :type prefix: str
+    :param prefix: subdirectory inside the tarball to put everything into (e.g. ``'mrjob'``)
     """
     if not os.path.isdir(dir):
         raise IOError('Not a directory: %r' % (dir,))
@@ -182,15 +191,17 @@ def tar_and_gzip(dir, out_path, filter=None):
     for dirpath, dirnames, filenames in os.walk(dir):
         for filename in filenames:
             path = os.path.join(dirpath, filename)
-            # janky version of os.path.relpath (Python 2.6):
-            path_in_tar_gz = path[len(os.path.join(dir, '')):]
-            if filter(path_in_tar_gz):
+            # janky version of os.path.relpath() (Python 2.6):
+            rel_path = path[len(os.path.join(dir, '')):]
+            if filter(rel_path):
                 # copy over real files, not symlinks
                 real_path = os.path.realpath(path)
+                path_in_tar_gz = os.path.join(prefix, rel_path)
                 tar_gz.add(real_path, arcname=path_in_tar_gz, recursive=False)
 
     tar_gz.close()
 
+
 def unarchive(archive_path, dest):
     """Extract the contents of a tar or zip file at *archive_path* into the directory *dest*.
 
